@@ -50,10 +50,10 @@ var (
 			// Create custom hooks directory if it doesn't exist
 			customHooksPath := filepath.Join(cfg.DataPath, "hooks")
 			if _, err := os.Stat(customHooksPath); err != nil && os.IsNotExist(err) {
-				os.MkdirAll(customHooksPath, os.ModePerm) // nolint: errcheck
+				os.MkdirAll(customHooksPath, os.ModePerm) //nolint: errcheck
 				// Generate update hook example without executable permissions
 				hookPath := filepath.Join(customHooksPath, "update.sample")
-				// nolint: gosec
+				//nolint: gosec
 				if err := os.WriteFile(hookPath, []byte(updateHookExample), 0o744); err != nil {
 					return fmt.Errorf("failed to generate update hook example: %w", err)
 				}
@@ -62,7 +62,7 @@ var (
 			// Create log directory if it doesn't exist
 			logPath := filepath.Join(cfg.DataPath, "log")
 			if _, err := os.Stat(logPath); err != nil && os.IsNotExist(err) {
-				os.MkdirAll(logPath, os.ModePerm) // nolint: errcheck
+				os.MkdirAll(logPath, os.ModePerm) //nolint: errcheck
 			}
 
 			db := db.FromContext(ctx)
@@ -86,7 +86,7 @@ var (
 			done := make(chan os.Signal, 1)
 			doneOnce := sync.OnceFunc(func() { close(done) })
 
-			signal.Notify(done, os.Interrupt, syscall.SIGINT, syscall.SIGTERM)
+			signal.Notify(done, os.Interrupt, syscall.SIGINT, syscall.SIGTERM, syscall.SIGHUP)
 
 			// This endpoint is added for testing purposes
 			// It allows us to stop the server from the test suite.
@@ -107,12 +107,23 @@ var (
 				doneOnce()
 			}()
 
-			select {
-			case err := <-lch:
-				if err != nil {
-					return fmt.Errorf("server error: %w", err)
+			for {
+				select {
+				case err := <-lch:
+					if err != nil {
+						return fmt.Errorf("server error: %w", err)
+					}
+				case sig := <-done:
+					if sig == syscall.SIGHUP {
+						s.logger.Info("received SIGHUP signal, reloading TLS certificates if enabled")
+						if err := s.ReloadCertificates(); err != nil {
+							s.logger.Error("failed to reload TLS certificates", "err", err)
+						}
+						continue
+					}
 				}
-			case <-done:
+
+				break
 			}
 
 			ctx, cancel := context.WithTimeout(ctx, 5*time.Second)
