@@ -4,15 +4,15 @@ import (
 	"context"
 	"fmt"
 
+	"charm.land/log/v2"
 	"github.com/alecthomas/chroma/v2/lexers"
-	zone "github.com/aymanbagabas/bubblezone/v2"
-	"github.com/charmbracelet/log/v2"
 	"github.com/charmbracelet/soft-serve/git"
 	"github.com/charmbracelet/soft-serve/pkg/backend"
 	"github.com/charmbracelet/soft-serve/pkg/config"
 	"github.com/charmbracelet/soft-serve/pkg/ui/keymap"
 	"github.com/charmbracelet/soft-serve/pkg/ui/styles"
 	"github.com/charmbracelet/ssh"
+	zone "github.com/lrstanley/bubblezone/v2"
 )
 
 type contextKey struct {
